@@ -2,80 +2,79 @@
 
 # load module
 clear all;
-example;
+swigexample;
 assert(cvar.ivar == ifunc);
-assert(exist("example","var"));
+assert(exist("swigexample","var"));
 clear all
-example;
+swigexample;
 assert(cvar.ivar == ifunc);
-assert(exist("example","var"));
+assert(exist("swigexample","var"));
 clear all
 
 # load module in a function globally before base context
 clear all;
 function testme
-  example;
+  swigexample;
   assert(cvar.ivar == ifunc);
-  assert(exist("example","var"));
+  assert(exist("swigexample","var"));
 endfunction
 testme
 testme
-example;
+swigexample;
 assert(cvar.ivar == ifunc);
-assert(exist("example","var"));
+assert(exist("swigexample","var"));
 clear all
 function testme
-  example;
+  swigexample;
   assert(cvar.ivar == ifunc);
-  assert(exist("example","var"));
+  assert(exist("swigexample","var"));
 endfunction
 testme
 testme
-example;
+swigexample;
 assert(cvar.ivar == ifunc);
-assert(exist("example","var"));
+assert(exist("swigexample","var"));
 clear all
 
 # load module in a function globally after base context
 clear all;
-example;
+swigexample;
 assert(cvar.ivar == ifunc);
-assert(exist("example","var"));
+assert(exist("swigexample","var"));
 function testme
-  example;
+  swigexample;
   assert(cvar.ivar == ifunc);
-  assert(exist("example","var"));
+  assert(exist("swigexample","var"));
 endfunction
 testme
 testme
 clear all
-example;
+swigexample;
 assert(cvar.ivar == ifunc);
-assert(exist("example","var"));
+assert(exist("swigexample","var"));
 function testme
-  example;
+  swigexample;
   assert(cvar.ivar == ifunc);
-  assert(exist("example","var"));
+  assert(exist("swigexample","var"));
 endfunction
 testme
 testme
 clear all
 
-# octave 3.0.5 randomly crashes on the remaining tests, so skip them
-api_version = sscanf(octave_config_info("api_version"), "api-v%i");
-if api_version < 37
+# octave 3.0.5 randomly crashes on the remaining tests
+if !swig_octave_prereq(3,2,0)
   exit
 endif
 
 # load module with no cvar
 clear all;
-example2;
-assert(example2.ivar == ifunc);
-assert(exist("example2","var"));
+swigexample2;
+assert(swigexample2.ivar == ifunc);
+assert(exist("swigexample2","var"));
 assert(!isglobal("cvar"))
 clear all
-example2;
-assert(example2.ivar == ifunc);
-assert(exist("example2","var"));
+swigexample2;
+assert(swigexample2.ivar == ifunc);
+assert(exist("swigexample2","var"));
 assert(!isglobal("cvar"))
 clear all
