@@ -256,6 +256,7 @@
 #define WARN_JAVA_TYPEMAP_JAVAIN_UNDEF        818
 #define WARN_JAVA_TYPEMAP_JAVADIRECTORIN_UNDEF    819
 #define WARN_JAVA_TYPEMAP_JAVADIRECTOROUT_UNDEF   820
+#define WARN_JAVA_TYPEMAP_INTERFACECODE_UNDEF 821
 #define WARN_JAVA_COVARIANT_RET               822
 #define WARN_JAVA_TYPEMAP_JAVACONSTRUCT_UNDEF 823
 #define WARN_JAVA_TYPEMAP_DIRECTORIN_NODESC   824
@@ -275,6 +276,7 @@
 #define WARN_CSHARP_TYPEMAP_CSIN_UNDEF        838
 #define WARN_CSHARP_TYPEMAP_CSDIRECTORIN_UNDEF    839
 #define WARN_CSHARP_TYPEMAP_CSDIRECTOROUT_UNDEF   840
+#define WARN_CSHARP_TYPEMAP_INTERFACECODE_UNDEF   841
 #define WARN_CSHARP_COVARIANT_RET             842
 #define WARN_CSHARP_TYPEMAP_CSCONSTRUCT_UNDEF 843
 #define WARN_CSHARP_EXCODE                    844
