@@ -7,7 +7,7 @@ def get_cflags(language, std, compiler):
     cflags = {
         "csharp":"-Werror " + c_common,
              "d":"-Werror " + c_common,
-            "go":"-Werror " + c_common,
+            "go":"-Werror " + c_common + " -Wno-declaration-after-statement",
          "guile":"-Werror " + c_common,
           "java":"-Werror " + c_common,
     "javascript":"-Werror " + c_common,
@@ -47,7 +47,7 @@ def get_cxxflags(language, std, compiler):
         "python":"-Werror " + cxx_common,
              "r":"-Werror " + cxx_common,
           "ruby":"-Werror " + cxx_common,
-        "scilab":             cxx_common,
+        "scilab":"-Werror " + cxx_common,
            "tcl":"-Werror " + cxx_common,
     }
     if compiler == 'clang':
